@@ -1,8 +1,8 @@
 #' Create, test for and print affine matrices
 #' 
 #' \code{isAffine} returns a logical value indicating whether its argument is,
-#' or resembles, a 4x4 affine matrix. \code{asAffine} converts a suitable
-#' matrix to the affine class, attaching the source and target images as
+#' or resembles, a 4x4 affine matrix. \code{asAffine} converts other objects to
+#' the affine class, attaching or updating the source and target image
 #' attributes. Affine transformations are a class of linear transformations
 #' which preserve points, straight lines and planes, and may consist of a
 #' combination of rotation, translation, scale and skew operations.
@@ -15,11 +15,14 @@
 #' @param strict If \code{TRUE}, this function just tests whether the object is
 #'   of class \code{"affine"}. Otherwise it also tests for an affine-like 4x4
 #'   matrix.
-#' @param source,target Source and target images for the transformation.
+#' @param source,target New source and target images for the transformation.
 #' @param x An \code{"affine"} object.
-#' @param ... Additional parameters to methods. Currently unused.
-#' @return A logical value, which is \code{TRUE} if \code{object} appears to be
-#'   an affine matrix.
+#' @param ... Additional parameters to methods.
+#' @param i The transformation number, for \code{niftyreg} objects containing
+#'   more than one.
+#' @return For \code{isAffine}, a logical value, which is \code{TRUE} if
+#'   \code{object} appears to be an affine matrix. For \code{asAffine}, a
+#'   classed affine object with source and target attributes set appropriately.
 #' 
 #' @note 2D affines are a subset of 3D affines, and are stored in a 4x4 matrix
 #'   for internal consistency, even though a 3x3 matrix would suffice.
@@ -29,7 +32,7 @@
 #' @export
 isAffine <- function (object, strict = FALSE)
 {
-    if ("affine" %in% class(object))
+    if (inherits(object, "affine"))
         return (TRUE)
     else if (!strict && is.matrix(object) && isTRUE(all.equal(dim(object), c(4,4))))
         return (TRUE)
@@ -40,23 +43,55 @@ isAffine <- function (object, strict = FALSE)
 
 #' @rdname affine
 #' @export
-asAffine <- function (object, source = NULL, target = NULL)
+asAffine <- function (object, source = NULL, target = NULL, ...)
 {
-    if ("affine" %in% class(object) && is.null(source) && is.null(target))
-        return (object)
-    else
-        object <- as.matrix(object)
+    UseMethod("asAffine")
+}
+
+#' @rdname affine
+#' @method asAffine niftyreg
+#' @export
+asAffine.niftyreg <- function (object, source = NULL, target = NULL, i = 1L, ...)
+{
+    asAffine(forward(object, i))
+}
+
+#' @rdname affine
+#' @export
+asAffine.affine <- function (object, source = NULL, target = NULL, ...)
+{
+    return (xfmAttrib(object, source, target, ...))
+}
+
+#' @rdname affine
+#' @export
+asAffine.niftiImage <- function (object, source = attr(object,"source"), target = attr(object,"target"), ...)
+{
+    # For some reason, NiftyReg stores the half transform twice
+    halfTransforms <- lapply(extensions(object), function(ext) {
+        values <- readBin(ext, "numeric", 16L, 4L)
+        return (matrix(values, nrow=4L, ncol=4L, byrow=TRUE))
+    })
+    
+    if (length(halfTransforms) != 2L)
+        stop("NiftyReg embedded affine is not present, or in an unexpected form")
+    else if (object$intent_name != "NREG_TRANS")
+        warning("This image doesn't look like a NiftyReg transform; results may be misleading")
+    
+    transform <- do.call("%*%", halfTransforms)
+    return (xfmAttrib(transform, source, target, class="affine"))
+}
+
+#' @rdname affine
+#' @export
+asAffine.default <- function (object, source = NULL, target = NULL, ...)
+{
+    object <- as.matrix(object)
     
     if (!isTRUE(all.equal(dim(object), c(4,4))))
         stop("Affine matrix should be 4x4")
     
-    object <- structure(object, source=source, target=target, class="affine")
-    if (!is.null(source) && !("niftiImage" %in% class(source)))
-        attr(object,"source") <- retrieveNifti(attr(object,"source"))
-    if (!is.null(target) && !("niftiImage" %in% class(target)))
-        attr(object,"target") <- retrieveNifti(attr(object,"target"))
-    
-    return (object)
+    return (xfmAttrib(object, source, target, class="affine"))
 }
 
 
@@ -65,8 +100,8 @@ asAffine <- function (object, source = NULL, target = NULL)
 print.affine <- function (x, ...)
 {
     cat("NiftyReg affine matrix:\n")
-    lines <- apply(format(x,scientific=FALSE), 1, paste, collapse="  ")
-    cat(paste(lines, collapse="\n"))
+    lines <- apply(format(round(x,6),scientific=FALSE), 1, paste, collapse="  ")
+    cat(paste0("  ",lines), sep="\n")
     
     source <- attr(x, "source")
     if (!is.null(source))
@@ -285,7 +320,7 @@ buildAffine <- function (translation = c(0,0,0), scales = c(1,1,1), skews = c(0,
 {
     if (is.null(source))
         stop("Source image must be specified")
-    source <- retrieveNifti(source)
+    source <- asNifti(source, internal=TRUE)
     
     if (is.list(translation))
         x <- translation
@@ -315,7 +350,7 @@ buildAffine <- function (translation = c(0,0,0), scales = c(1,1,1), skews = c(0,
         }
     }
     else
-        target <- retrieveNifti(target)
+        target <- asNifti(target, internal=TRUE)
     
     if (ndim(source) != ndim(target))
         stop("Source and target images must be of the same dimensionality")
